OC.L10N.register(
    "settings",
    {
    "Private" : "פרטי",
    "Local" : "מקומ",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "לסנכרן מול שרתים מהימנים בלבד",
    "Synchronize to trusted servers and the global and public address book" : "לסנכרן מול שרתים מהימנים וספר הכתובות הגלובלי והציבורי",
    "Verify" : "אימות",
    "Verifying …" : "מתבצע אימות…",
    "Unable to change password" : "לא ניתן לשנות את הססמה",
    "Very weak password" : "סיסמא מאוד חלשה",
    "Weak password" : "סיסמא חלשה",
    "So-so password" : "סיסמא ככה-ככה",
    "Good password" : "סיסמא טובה",
    "Strong password" : "סיסמא חזקה",
    "An error occurred while changing your language. Please reload the page and try again." : "אירעה שגיאה בעת החלפת השפה שלך. נא לטעון את העמוד מחדש ולנסות שוב.",
    "An error occurred while changing your locale. Please reload the page and try again." : "אירעה שגיאה בעת החלפת ההגדרות האזוריות שלך. נא לטעון את העמוד מחדש ולנסות שוב.",
    "Week starts on {fdow}" : "השבוע מתחיל ב{fdow}",
    "Groups" : "קבוצות",
    "Group list is empty" : "רשימת הקבוצות ריקה",
    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
    "{actor} added you to group {group}" : "נוספת לקבוצה {group} על ידי {actor}",
    "You added {user} to group {group}" : "הוספת את {user} לקבוצה {group}",
    "{actor} added {user} to group {group}" : "ההוספה של {user} לקבוצה {group} נעשתה על ידי {actor}",
    "An administrator added you to group {group}" : "נוספת לקבוצה {group} על ידי מנהל",
    "An administrator added {user} to group {group}" : "מנהל הוסיף את {user} לקבוצה {group}",
    "{actor} removed you from group {group}" : "הוסרת מהקבוצה {group} על ידי {actor}",
    "You removed {user} from group {group}" : "הסרת את {user} מהקבוצה {group}",
    "{actor} removed {user} from group {group}" : "ההסרה של {user} מהקבוצה {group} בוצעה על ידי {actor}",
    "An administrator removed you from group {group}" : "מנהל הסיר אותך מהקבוצה {group}",
    "An administrator removed {user} from group {group}" : "מנהל הסיר את {user} מהקבוצה {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>חברותך בקבוצות</strong> השתנתה",
    "{actor} changed your password" : "הססמה שלך הוחלפה על ידי {actor}",
    "You changed your password" : "שינית את הססמה שלך",
    "Your password was reset by an administrator" : "הססמה שלך אופסה על ידי מנהל",
    "Your password was reset" : "הססמה שלך אופסה",
    "{actor} changed your email address" : "כתובת הדוא״ל שלך נערכה על ידי {actor}",
    "You changed your email address" : "שינית את כתובת הדוא״ל שלך",
    "Your email address was changed by an administrator" : "כתובת הדוא״ל שלך נערכה על ידי המנהל",
    "You created app password \"{token}\"" : "יצרת ססמה „{token}” ליישומון",
    "You deleted app password \"{token}\"" : "מחקת ססמה „{token}” ליישומון",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "החלפת את שם ססמת היישומון „{token}” לשם „{newToken}”",
    "You granted filesystem access to app password \"{token}\"" : "הענקת גישה למערכת הקבצים לססמת היישומון „{token}”",
    "You revoked filesystem access from app password \"{token}\"" : "שללת גישה למערכת הקבצים מססמת היישומון „{token}”",
    "Security" : "אבטחה",
    "You successfully logged in using two-factor authentication (%1$s)" : "נכנסת בהצלחה באמצעות אימות דו־שלבי (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "ניסיון כניסה עם אימות דו־שלבי נכשל (%1$s)",
    "Remote wipe was started on %1$s" : "השמדת נתונים מרוחקת החלה ב־%1$s",
    "Remote wipe has finished on %1$s" : "השמדת נתונים מרוחקת הסתיימה ב־%1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "ה<strong>סמסה</strong> או <strong>כתוב הדוא״ל שלך</strong> השתנו",
    "Wrong password" : "ססמה שגויה",
    "Saved" : "נשמר",
    "No user supplied" : "לא סופק שם משתמש",
    "Authentication error" : "שגיאת אימות",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
    "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL משתמש בגרסה של %1$s שתוקפה פג (%2$s). נא לעדכן את מערכת ההפעלה או שתכונות כמו %3$s לא תפעלנה בצורה אמינה.",
    "Invalid SMTP password." : "ססמת ה־SMTP שגויה.",
    "Email setting test" : "בדיקת הגדרת דוא״ל",
    "Well done, %s!" : "עבודה יפה, %s!",
    "If you received this email, the email configuration seems to be correct." : "אם קיבלת את הדוא״ל הזה, כנראה שתצורת הדוא״ל נכונה.",
    "Email could not be sent. Check your mail server log" : "לא ניתן לשלוח דוא״ל. נא לבדוק את רישומי שרת הדוא״ל שלך.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "בעיה אירעה בשליחת הדואר האלקטרוני. יש לשנות את ההגדרות שלך. (שגיאה: %s)",
    "Invalid user" : "משתמש שגוי",
    "Invalid mail address" : "כתובת דואר אלקטרוני לא חוקית",
    "Settings saved" : "הגדרות נשמרו",
    "Unable to change full name" : "לא ניתן לשנות שם מלא",
    "Unable to change email address" : "לא ניתן לשנות את כתובת הדוא״ל",
    "Unable to set invalid phone number" : "לא ניתן להגדיר מספר טלפון שגוי",
    "Some account data was invalid" : "חלק מנתוני החשבון היו שגויים",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "כדי לאמת את חשבון הטוויטר שלך, עליך לפרסם את הציוץ הבא בטוויטר (נא לוודא שהוא יפורסם ללא ירידות שורה):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "כדי לאמת את האר של, עליך לאחסן את התוכן הבא בשורש האתר שלך תחת ‚‎.well-known/CloudIdVerificationCode.txt’ (עליך לוודא שכל הטקסט הזה מופיע בשורה אחת):",
    "%1$s changed your password on %2$s." : "ססמת ב‏־%2$s הוחלפה על ידי %1$s.",
    "Your password on %s was changed." : "הססמה שלך ב־%s הוחלפה.",
    "Your password on %s was reset by an administrator." : "ססמתך ב־%s אופסה על ידי נציגות מההנהלה.",
    "Your password on %s was reset." : "הססמה שלך על %s אופסה.",
    "Password for %1$s changed on %2$s" : "הססמה עבור %1$s הוחלפה ב־%2$s",
    "Password changed for %s" : "הוחלפה הססמה של %s",
    "If you did not request this, please contact an administrator." : "אם לא ביקשת זאת, נא ליצור קשר עם מנהל המערכת.",
    "Your email address on %s was changed." : "כתובת הדוא״ל שלך ב־%s הוחלפה",
    "Your email address on %s was changed by an administrator." : "כתובת הדוא״ל שלך ב־%s הוחלפה על ידי נציגות ההנהלה.",
    "Email address for %1$s changed on %2$s" : "כתובת הדוא״ל עבור %1$s הוחלפה ב־%2$s",
    "Email address changed for %s" : "כתובת הדוא״ל של %s הוחלפה",
    "The new email address is %s" : "כתובת הדוא״ל החדשה היא %s",
    "Your %s account was created" : "חשבון %s שלך נוצר",
    "Welcome aboard" : "ברוך בואך",
    "Welcome aboard %s" : "ברוך בואך %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "ברוך בואך לחשבונך ב־%s, יש לך את האפשרות להוסיף, להגן ולשתף את הנתונים שלך.",
    "Your username is: %s" : "שם המשתמש שלך הוא: %s",
    "Set your password" : "הגדרת הססמה שלך",
    "Go to %s" : "מעבר אל %s",
    "Install Client" : "התקנת לקו",
    "Logged in user must be a subadmin" : "המשתמש שנכנס חייב להיות תת־מנהל",
    "Apps" : "יישומונים",
    "Settings" : "הגדרות",
    "Personal" : "אישי",
    "Administration" : "ניהול",
    "Additional settings" : "הגדרות נוספות",
    "Groupware" : "קבוצתי",
    "Overview" : "סקירה",
    "Basic settings" : "הגדרות בסיסיות",
    "Sharing" : "שיתוף",
    "Personal info" : "פרטים אישיים",
    "Mobile & desktop" : "נייד ושולחן עבודה",
    "Email server" : "שרת דואר אלקטרוני",
    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
    "Background jobs" : "משימות רקע",
    "Create" : "יצירה",
    "Change" : "שינוי",
    "Delete" : "מחיקה",
    "Reshare" : "שיתוף מחדש",
    "Unlimited" : "ללא הגבלה",
    "Verifying" : "מתבצע אימות",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "משימת רקע שבודקת את אישורי ה־SSL בייבוא המשתמש ממתינה. נא לדגום את הדף הזה שוב בהמשך.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "יש כמה אישורי SSL מיובאים קיימים שאינם בשימוש עוד ב־Nextcloud 21. אפשר לייבא אותם בשורת הפקודה עם הפקודה „occ security:certificates:import”. הנתיבים שלהם בתור תיקיית הנתונים מופיעים להלן.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "תצורת ההצפנה מצד השרת המיושנת מופעלת. אנו ממליצים להשבית אותה.",
    "Nextcloud settings" : "הגדרות Nextcloud",
    "None" : "כלום",
    "Two-Factor Authentication" : "אימות דו־שלבי",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "ניתן לאכוף אימות דו־שלבי על כל המשתמשים ועל קבוצות מסוימות. אם אין להם ספק אימות דו־שלבי מוגדר, לא תהיה להם אפשרות להיכנס למערכת.",
    "Enforce two-factor authentication" : "אכיפת אימות דו־שלבי",
    "Limit to groups" : "הגבלה לקבוצות",
    "Enforcement of two-factor authentication can be set for certain groups only." : "ניתן להגדיר אכיפה של אימות דו־שלבי על קבוצות מסוימות בלבד.",
    "Two-factor authentication is enforced for all members of the following groups." : "אימות דו־שלבי נאכף על כל החברים בקבוצות הבאות.",
    "Enforced groups" : "קבוצות נאכפות",
    "Two-factor authentication is not enforced for members of the following groups." : "אימות דו־שלבי לא נאכף על החברים בקבוצות הבאות.",
    "Excluded groups" : "קבוצות חריגות",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "כאשר קבוצות נבחרות/מוחרגות, הן משתמשות בלוגיקה הבאה כדי להחליט האם נאכף על המשתמש אימות דו־שלבי: אם לא נבחרו קבוצות, אימות דו־שלבי פעיל עבור כולם למעט החברים בקבוצות שהוחרגו. אם נבחרו קבוצות, אימות דו־שלבי מופעל לכל החברים של הקבוצות האלו. אם משתמש נמצא גם בקבוצה נבחרת וגם בקבוצה מוחרגת, הנבחרת מקבלת עדיפות ואימות דו־שלבי נאכף.",
    "Save changes" : "שמירת שינויים",
    "All" : "הכל",
    "Limit app usage to groups" : "הגבלת השימוש ביישומון לקבוצות",
    "No results" : "אין תוצאות",
    "Update to {version}" : "עדכון ל־{version}",
    "Remove" : "הסרה",
    "Disable" : "ניטרול",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
    "View in store" : "הצגה באחסון",
    "Visit website" : "ביקור באתר האינטרנט",
    "Report a bug" : "דיווח על באג",
    "User documentation" : "תיעוד משתמש",
    "Admin documentation" : "תיעוד מנהל",
    "Developer documentation" : "תיעוד מפתח",
    "This app is supported via your current Nextcloud subscription." : "יישומון זה נתמך על ידי מינוי ה־Nextcloud הנוכחי שלך.",
    "Supported" : "נתמך",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "היישומונים המומלצים מפותחים על ידי ובתוך הקהילה. הם מציעים תכונות ליבה מסוימות והן מוכנות לשימוש יומיומי.",
    "Featured" : "מומלץ",
    "Update to {update}" : "עדכון ל־{version}",
    "Results from other categories" : "תוצאות מקטגוריות אחרות",
    "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
    "Disable all" : "להשבית הכול",
    "Enable all" : "הפעלת הכול",
    "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
    "Marked for remote wipe" : "מסומן להשמדת נתונים מרחוק",
    "Device settings" : "הגדרות מכשיר",
    "Allow filesystem access" : "לאפשר גישה למערכת הקבצים",
    "Rename" : "שינוי שם",
    "Revoke" : "שלילה",
    "Wipe device" : "השמדת נתוני מכשיר",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome עבור Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Sync client - {os}" : "לקוח סנכרון - {os}",
    "This session" : "הפעלה זו",
    "Device" : "התקן",
    "Last activity" : "פעילות אחרונה",
    "Devices & sessions" : "התקנים והפעלות",
    "Web, desktop and mobile clients currently logged in to your account." : "לקוחות שמחוברים כעת לחשבון שלך דרך דפדפן, שולחן עבודה והתקנים ניידים.",
    "Do you really want to wipe your data from this device?" : "להשמיד את הנתונים שלך במכשיר הזה?",
    "Confirm wipe" : "אישור ההשמדה",
    "Error while creating device token" : "שגיאה בזמן יצירת מחרוזת התקן",
    "Error while updating device token scope" : "שגיאה בעדכון טווח אסימון מכשירים",
    "Error while updating device token name" : "שגיאה בעת עדכון שם אסימון המכשיר",
    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
    "Error while wiping the device with the token" : "שגיאה בעת השמדת נתוני המכשיר עם האסימון",
    "App name" : "שם יישום",
    "Create new app password" : "יצירת סיסמת יישום חדשה",
    "Use the credentials below to configure your app or device." : "יש להשתמש בפרטי הזיהוי שלהלן כדי להגדיר את היישומון או ההתקן שלך.",
    "For security reasons this password will only be shown once." : "מטעמי אבטחה הססמה תופיע פעם אחת בלבד.",
    "Username" : "שם משתמש",
    "Password" : "ססמה",
    "Done" : "הסתיים",
    "Show QR code for mobile apps" : "הצגת קוד QR ליישומונים לניידים",
    "Copied!" : "הועתק!",
    "Copy" : "העתקה",
    "Could not copy app password. Please copy it manually." : "לא ניתן להעתיק את הססמה של היישומון. נא להעתיק אותה ידנית.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "כדי להריץ זאת יש צורך בהרחבת POSIX ל־PHP. נא לעיין ב{linkstart}תיעוד של PHP{linkend} לפרטים נוספים.",
    "Profile" : "פרופיל",
    "Enable" : "הפעלה",
    "Server-side encryption" : "הצפנת צד שרת",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "הצפנה בצד השרת מאפשרת להצפין קבצים שנשלחים לשרת. לתכונה זו יש מגבלות כגון ירידה בביצועים, מומלץ להפעיל רק אם יש צורך.",
    "Enable server-side encryption" : "הפעלת הצפנה בצד שרת",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "ברגע שהצפנה מופעלת, כל הקבצים שיועלו לשרת מרגע זה יהיו מוצפנים בשרת. ניתן יהיה לנטרל את ההצפנה בעתיד רק אם מודול ההצפנה תומך בפונקציה זו, וכל התנאים המוקדמים (דהיינו הגדרת מפתח השחזור) מתקיימים.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "הצפנה לבד אינה מספיקה לאבטחה איכותית למערכת. נא לעיין בתיעוד לקבלת פרטים נוספים על אופן הפעולה של יישומון ההצפנה ודרכי היישום הנתמכות.",
    "Be aware that encryption always increases the file size." : "תשומת לב לכך שהצפנה בהכרח מגדילה את גודל הקובץ.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "תמיד טוב ליצור גיבוי קבוע למידע , במקרה של הצפנה יש לוודא שגם מפתחות ההצפנה מגובים עם המידע שלך.",
    "This is the final warning: Do you really want to enable encryption?" : "זו הזהרה אחרונה: האם באמת ברצונך להפעיל הצפנה?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "לא נמצא מודול הצפנה, יש לאפשר מודול הצפנה בתפריט היישומים.",
    "Select default encryption module:" : "יש לבחור מודול הצפנת ברירת מחדל:",
    "Remove group" : "הסרת קבוצה",
    "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
    "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
    "Current password" : "סיסמא נוכחית",
    "New password" : "סיסמא חדשה",
    "Change password" : "שינוי סיסמא",
    "png or jpg, max. 20 MB" : "png או jpg, מקסימום 20 מגה-בייט",
    "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
    "Cancel" : "ביטול",
    "Your email address" : "כתובת הדואר האלקטרוני שלך",
    "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
    "Language" : "שפה",
    "Help translate" : "עזרה בתרגום",
    "No language set" : "לא הוגדרה שפה",
    "Your phone number" : "מספר הטלפון שלך",
    "Add" : "הוספה",
    "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
    "Add new password" : "הוספת ססמה חדשה",
    "Add new email address" : "הוספת כתובת דוא״ל חדשה",
    "Set user as admin for" : "הגדרת משתמש כהנהלה של",
    "Select user quota" : "בחירת מכסת משתמש",
    "Delete user" : "מחיקת משתמש",
    "Wipe all devices" : "השמדת נתוני כל המכשירים",
    "Disable user" : "השבתת משתמש",
    "Enable user" : "הפעלת משתמש",
    "Resend welcome email" : "שליחת הודעת קבלת פנים בדוא״ל מחדש",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
    "Remote wipe of devices" : "השמדת נתונים מרוחקת במכשירים",
    "Wipe {userid}'s devices" : "השמדת נתוני המכשירים של {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "למחוק לחלוטין את החשבון של {userid} לרבות כל הקבצים האישיים, נתוני היישומונים וכו׳.",
    "Account deletion" : "מחיקת חשבון",
    "Delete {userid}'s account" : "מחיקת החשבון של {userid}",
    "Welcome mail sent!" : "נשלחה הודעת קבלת פנים בדוא״ל!",
    "Edit User" : "עריכת משתמש",
    "Toggle user actions menu" : "החלפת מצב תפריט פעולות משתמש",
    "{size} used" : "{size} בשימוש",
    "New user" : "משתמש חדש",
    "Will be autogenerated" : "ייווצר אוטומטית",
    "Display name" : "שם תצוגה",
    "Email" : "דוא״ל",
    "Default language" : "שפת בררת מחדל",
    "Add a new user" : "הוספת משתמש חדש",
    "Group admin for" : "הנהלת הקבוצה",
    "Quota" : "מכיסה",
    "User backend" : "מנגנון משתמש",
    "Storage location" : "מיקום אחסון",
    "Last login" : "כניסה אחרונה",
    "No users in here" : "אין כאן משתמשים",
    "Default quota" : "מיכסת בררת מחדל",
    "Common languages" : "שפות נפוצות",
    "Password change is disabled because the master key is disabled" : "החלפת ססמה מושבתת כיוון שהמפתח הראשי מושבת",
    "Passwordless authentication requires a secure connection." : "אימות ללא ססמה דורש חיבור מוצפן.",
    "Add WebAuthn device" : "הוספת התקן WebAuthn",
    "Please authorize your WebAuthn device." : "נא לייפות את כוחו של התקן ה־WebAuthn שלך.",
    "Name your device" : "מתן שם להתקן שלך",
    "Adding your device …" : "הוספת ההתקן שלך…",
    "Server error while trying to add WebAuthn device" : "אירעה שגיאת שרת בעת הניסיון להוספת התקן WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "התקבלה שגיאת שרת בעת הניסיון להשלים את הרשמת התקן ה־WebAuthn",
    "Unnamed device" : "התקן ללא שם",
    "Passwordless Authentication" : "אימות ללא ססמה",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "הגדרת החשבון שלך לאימות ללא ססמה לפי תקן FIDO2.",
    "No devices configured." : "לא הוגדרו התקנים.",
    "The following devices are configured for your account:" : "ההתקנים הבאים הוגדרו לחשבון שלך:",
    "Your browser does not support WebAuthn." : "הדפדפן שלך אינו תומך ב־WebAuthn.",
    "Your apps" : "היישומונים שלך",
    "Active apps" : "יישומונים פעילים",
    "Disabled apps" : "יישומונים מושבתים",
    "Updates" : "עדכונים",
    "App bundles" : "מאגדי יישומונים",
    "Featured apps" : "יישומונים מובילים",
    "{license}-licensed" : "ברישיון {license}",
    "Details" : "פרטים",
    "Changelog" : "יומן שינויים",
    "by {author}\n{license}" : "מאת {author}\n{license}",
    "Enter group name" : "נא להקליד שם קבוצה",
    "Add group" : "הוספת קבוצה",
    "Active users" : "משתמשים פעילים",
    "Admins" : "מנהלים",
    "Disabled users" : "משתמשים מושבתים",
    "Default quota:" : "מכסת בררת מחדל:",
    "Select default quota" : "בחירת מכסת בררת מחדל",
    "Show Languages" : "הצגת שפות",
    "Show last login" : "הצגת כניסה אחרונה",
    "Show user backend" : "הצגת צד אחורי למשתמש",
    "Show storage path" : "הצגת נתיב אחסון",
    "Send email to new user" : "שליחת דואר אלקטרוני למשתמש חדש",
    "Not saved" : "לא נשמר",
    "Sending…" : "בשליחה…",
    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
    "Location" : "מיקום",
    "Profile picture" : "תמונת פרופיל",
    "About" : "על אודות",
    "Full name" : "שם מלא",
    "Phone number" : "מספר טלפון",
    "Twitter" : "טוויטר",
    "Website" : "אתר",
    "Hide" : "הסתרה",
    "Download and enable" : "להוריד ולהפעיל",
    "Enable untested app" : "לאפשר יישומון שלא נבדק",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
    "Never" : "מעולם לא",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
    "Administrator documentation" : "תיעוד מנהל",
    "Documentation" : "תיעוד",
    "Forum" : "פורום",
    "Login" : "התחברות",
    "Plain" : "רגיל",
    "NT LAN Manager" : "מנהל רשת NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "תיעוד פתוח",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "חשוב להגדיר את השרת הזה כדי שיתאפשר לשלוח דרכו הודעות דוא״ל, למשל כדי לאפס ססמה ולשלוח התרעות.",
    "Send mode" : "מצב שליחה",
    "Encryption" : "הצפנה",
    "Sendmail mode" : "מצב Sendmail (שליחת דוא״ל)",
    "From address" : "מכתובת",
    "Authentication method" : "שיטת אימות",
    "Authentication required" : "נדרש אימות",
    "Server address" : "כתובת שרת",
    "Port" : "שער",
    "Credentials" : "פרטי גישה",
    "SMTP Username" : "שם משתמש SMTP ",
    "SMTP Password" : "סיסמת SMTP",
    "Save" : "שמור",
    "Send email" : "שליחת דואר אלקטרוני",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
    "All checks passed." : "כל הבדיקות עברו",
    "There are some errors regarding your setup." : "ישנן מגוון שגיאות על ההגדרות שלך.",
    "There are some warnings regarding your setup." : "ישנן מגוון אזהרות על ההגדרות שלך.",
    "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "נא לעיין היטב ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">מדריכי ההתקנה ↖️</a> ולחפש אם מופיעות שגיאות או אזהרות ב<a href=\"%2$s\">יומן</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "בדיקת האבטחה של ה־Nextcloud שלך באמצעות <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">סריקת האבטחה שלנו ↖️</a>.",
    "Version" : "גרסה",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "כמנהל יש לך אפשרות לכוונן את התנהגות השיתוף. נא לעיין בתיעוד לפרטים נוספים.",
    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
    "Set default expiration date for shares" : "הגדרת תאריך תפוגה כבררת מחדל לשיתופים",
    "day(s)" : "ימים",
    "Enforce expiration date" : "חייב תאריך תפוגה",
    "Allow public uploads" : "אפשר העלאות ציבוריות",
    "Always ask for a password" : "תמיד לבקש ססמה",
    "Enforce password protection" : "חייב הגנת סיסמא",
    "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
    "Allow resharing" : "לאפשר שיתוף מחדש",
    "Allow sharing with groups" : "מאפשר שיתוף עם קבוצות",
    "Restrict users to only share with users in their groups" : "הגבלת משתמשים לשתף רק עם משתמשים בקבוצה שלהם",
    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
    "Allow username autocompletion in share dialog" : "לאפשר השלמה אוטומטית של שם משתמש בחלונית השיתוף",
    "Allow username autocompletion to users within the same groups" : "לאפשר השלמה אוטומטית של שם משתמש למשתמשים בתוך אותן הקבוצות",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "הצגת טקסט הבהרה בעמוד ההעלאה בקישור הציבורי (מופיע רק כאשר רשימת הקבצים מוסתרת)",
    "This text will be shown on the public link upload page when the file list is hidden." : "טקסט זה יופיע בקישור עמוד ההעלאה של הקישור הציבורי כאשר רשימת הקבצים מוסתרת.",
    "Default share permissions" : "הרשאות שיתוף כבררת מחדל",
    "Reasons to use Nextcloud in your organization" : "סיבות להשתמש ב־Nextcloud בארגון שלך",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר",
    "Follow us on Mastodon" : "למעקב אחרינו ב־Mastodon",
    "Check out our blog" : "לעיין בבלוג שלנו",
    "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
    "You are a member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
    "You are using <strong>%s</strong>" : "הניצולת שלך היא <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "מנוצלים <strong>%1$s</strong> מתוך <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Locale" : "הגדרות אזוריות",
    "Use a second factor besides your password to increase security for your account." : "ניתן להשתמש בגורם נוסף מלבד הססמה שלך כדי להגביר את אבטחת החשבון שלך.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
    "Migration started …" : "המרה החלה...",
    "Select a profile picture" : "יש לבחור תמונת פרופיל",
    "Couldn't remove app." : "לא ניתן להסיר את היישום.",
    "Couldn't update app." : "לא ניתן לעדכן את היישום.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "המנגנון אינו תומך בשינוי ססמה אך מפתח ההצפנה של המשתמש עודכן.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "לא ניתן לקבוע האם גרסת ה־TLS של cURL מיושנת או לא עקב שגיאה שהתרחשה במהלך בקשת ה־HTTPS מול https://nextcloud.com. נא לעיין בקובץ היומן של Nextcloud לקבלת פרטים נוספים.",
    "You need to set your user email before being able to send test emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לשלוח דואר אלקטרוני לבדיקה.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "שלילת האסימון הזו עשויה למנוע את השמדת נתוני המכשיר שלך אם ההשמדה טרם החלה.",
    "All languages" : "כל השפות",
    "Everyone" : "כולם",
    "An error occured during the request. Unable to proceed." : "אירעה שגיאה במהלך הבקשה. לא ניתן להמשיך.",
    "Test email settings" : "בדיקת הגדרות דואר אלקטרוני",
    "Please read carefully before activating server-side encryption: " : "יש לקרוא בתשומת לב רבה לפני שמפעילים הצפנת צד שרת:",
    "Enable encryption" : "אפשר הצפנה",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה. יש לאפשר את \"מודול הצפנה ברירת מחדש\" ולהריץ 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה.",
    "Start migration" : "התחלת המרה",
    "Last job execution ran %s. Something seems wrong." : "פעילות ההרצה האחרונה נמשכה %s. משהו שם נראה לא תקין.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "חלק מהמשימות לא הופעלו מאז %s. נא לשקול להגדיל את תדירות ההפעלה.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "חלק מהמשימות לא הופעלו מאז %s. נא לשקול לעבור ל־cron של המערכת.",
    "Last job ran %s." : "המשימה האחרונה רצה למשך %s.",
    "Background job didn’t run yet!" : "משימת הרקע לא רצה עדיין!",
    "Pick background job setting" : "בחירת הגדרות למשימת רקע",
    "Recommended" : "מומלץ",
    "The cron.php needs to be executed by the system user \"%s\"." : "יש להפעיל את cron.php בתור משתמש המערכת „%s”.",
    "days" : "ימים",
    "Upload new" : "העלאת חדש",
    "Select from Files" : "בחירה מתוך קבצים",
    "Remove image" : "הסרת תמונה",
    "Choose as profile picture" : "יש לבחור כתמונת פרופיל",
    "No display name set" : "לא נקבע שם תצוגה",
    "Address" : "כתובת",
    "Your postal address" : "כתובת הדואר שלך",
    "It can take up to 24 hours before the account is displayed as verified." : "יתכן שיעברו עד 24 שעות בטרם הצגת החשבון כמאומת.",
    "Link https://…" : "קישור https://…‎",
    "Twitter handle @…" : "כינוי בטוויטר @…",
    "Avatar" : "תמונה מייצגת"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
